==> dl.php?src=linea21_1_6.zip: linea21/languages/fr/lang_search.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "recherche";

$lang['search']['result'] = "Résultats de votre recherche";
$lang['search']['keywords'] = "Mot(s)-clef(s) : ";
$lang['search']['method'] = "Méthode : ";
$lang['search']['min_length']='Les éléments de votre recherche doivent comporter plus de 3 caractères';
$lang['search']['query_time']='traitement effectué en';
$lang['search']['query_seconds']='secondes';
$lang['search']['no_result'] = "aucun résultat";
$lang['search']['score'] = "indice de pertinence";
$lang['search']['score_abbr'] = "idp";
$lang['search']['score_not_good'] = "non fiable";

$lang['search']['one_of_them'] = "l'un de ces mots";
$lang['search']['all_of_them'] = "l'ensemble de ces mots";
$lang['search']['expression'] = "expression complète";
$lang['search']['text_button'] = "Lancer la recherche";

$lang['search']['comment_module'] = "Dans les commentaires";
$lang['search']['project_module'] = "Dans les projets";
$lang['search']['news_module'] = "Dans l'actualité";
$lang['search']['page_module'] = "Dans les pages";
$lang['search']['newsletter_module'] = "Dans les newsletters";
$lang['search']['publication_module'] = "Dans les dossiers";
$lang['search']['det_publication_module'] = "Dans les parties de dossiers";
$lang['search']['workshop_module'] = "Dans les groupes de travail";
$lang['search']['workshoprep_module'] = "Dans les rapports de groupes de travail";
$lang['search']['workshoprepcon_module'] = "Dans les parties de rapports de groupes de travail";
$lang['search']['workshopcal_module'] = "Dans les calendriers de groupes de travail";
$lang['search']['workshopcom_module'] = "Dans les discussions de groupes de travail";
$lang['search']['sdi_module'] = 'Dans les indicateurs de développement durable';
$lang['search']['yellowpages_module'] = "Dans l'annuaire des organisations";
$lang['search']['user_module'] = "Dans les utilisateurs inscrits";
$lang['search']['theme_module'] = "Dans les thèmes";
$lang['search']['scale_module'] = "Dans les échelles";
$lang['search']['level_module'] = "Dans les niveaux";

$lang['search']['help']="Moteur de recherche ".SITE_LINEA_NAME;
$lang['search']['help_list1']="Pour effectuer une recherche globale, cliquez sur l'icône \"loupe\" ou saisissez votre mot-clef directement dans la boite de texte sous le menu gauche";
$lang['search']['help_list2']="Pour effectuer une recherche par rubrique, allez dans cette rubrique et cliquez sur \"rechercher\"";
$lang['search']['help_list3']="L'indice de pertinence affiché est relatif aux documents trouvés par le moteur : le document le plus pertinent a l'indice le plus élevé.";

?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_search.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "recherche";

$lang['search']['result'] = "Résultats de votre recherche";
$lang['search']['keywords'] = "Mot(s)-clef(s) : ";
$lang['search']['method'] = "Méthode : ";
$lang['search']['min_length']='Les éléments de votre recherche doivent comporter au minimum 3 caractères';
$lang['search']['query_time']='traitement effectué en';
$lang['search']['query_seconds']='secondes';
$lang['search']['no_result'] = "aucun résultat";
$lang['search']['score'] = "indice de pertinence";
$lang['search']['score_abbr'] = "idp";
$lang['search']['score_not_good'] = "non fiable";

$lang['search']['one_of_them'] = "l'un de ces mots";
$lang['search']['all_of_them'] = "l'ensemble de ces mots";
$lang['search']['expression'] = "expression complète";
$lang['search']['text_button'] = "Lancer la recherche";

$lang['search']['comment_module'] = "Dans les commentaires";
$lang['search']['project_module'] = "Dans les projets";
$lang['search']['news_module'] = "Dans l'actualité";
$lang['search']['page_module'] = "Dans les pages";
$lang['search']['newsletter_module'] = "Dans les newsletters";
$lang['search']['publication_module'] = "Dans les publications";
$lang['search']['det_publication_module'] = "Dans les parties de publications";
$lang['search']['workshop_module'] = "Dans les groupes de travail";
$lang['search']['workshoprep_module'] = "Dans les rapports de groupes de travail";
$lang['search']['workshoprepcon_module'] = "Dans les parties de rapports de groupes de travail";
$lang['search']['workshopcal_module'] = "Dans les calendriers de groupes de travail";
$lang['search']['workshopcom_module'] = "Dans les discussions de groupes de travail";
$lang['search']['sdi_module'] = 'Dans les indicateurs de développement durable';
$lang['search']['yellowpages_module'] = "Dans l'annuaire des organisations";
$lang['search']['user_module'] = "Dans les utilisateurs inscrits";
$lang['search']['theme_module'] = "Dans les thèmes";
$lang['search']['scale_module'] = "Dans les échelles";
$lang['search']['level_module'] = "Dans les niveaux";

$lang['search']['help']="Moteur de recherche ".SITE_LINEA_NAME;
$lang['search']['help_list1']="Pour effectuer une recherche globale, cliquez sur l'icône \"loupe\" ou saisissez votre mot-clef directement dans la boite de texte sous le menu gauche";
$lang['search']['help_list2']="Pour effectuer une recherche par rubrique, allez dans cette rubrique et cliquez sur \"rechercher\"";
$lang['search']['help_list3']="L'indice de pertinence affiché est relatif aux documents trouvés par le moteur : le document le plus pertinent a l'indice le plus élevé.";

?>
